/* ============================================================================
 * AMES Wholesale Power Market Test Bed (Java): A Free Open-Source Test-Bed
 *         for the Agent-based Modeling of Electricity Systems
 * ============================================================================
 *
 * (C) Copyright 2013, by Hongyan Li, Junjie Sun, Sean L. Mooney and Leigh Tesfatsion
 *
 *    Homepage: http://www.econ.iastate.edu/tesfatsi/testMarketHome.htm
 *
 * LICENSING TERMS
 * The AMES Market Package is licensed by the copyright holders (Junjie Sun,
 * Hongyan Li, Sean L. Mooney, and Leigh Tesfatsion) as free open-source software under the
 * terms of the GNU General Public License (GPL). Anyone who is interested is
 * allowed to view, modify, and/or improve upon the code used to produce this
 * package, but any software generated using all or part of this code must be
 * released as free open-source software in turn. The GNU GPL can be viewed in
 * its entirety as in the following site: http://www.gnu.org/licenses/gpl.html
 */
package amesmarket;

/**
 * Defines an interface for objects to listen for
 * events from an ames market instance.
 *
 * Not well used yet. Intention is to use this interface
 * to replace the busy-waits for checking when the market has stopped running.
 *
 *<p>
 * The reason for defining another listening interface, instead of using
 * the one build into RePast is because of the way the stop actions are written.
 * The market schedule object ({@link AMESMarket#buildSchedule()}) does a bunch
 * of cleanup after the RePast stop event happens. This means an action listener
 * registered with RePast will try and act on the stop actions <b>BEFORE</b>
 * the market has done all of the finish clean-up.
 * <p>
 * There is a subtle dead-lock issue that can creep in to stop events. If any
 * of listeners wait for conditions to hold (e.g. the stop code > 0)
 * that are not set until after the market schedule object finishes
 * its end-of-market actions the whole system can freeze.
 * @author Sean L. Mooney
 *
 */
public interface AMESMarketListener {

    public void marketEvent(MarketEvent e);

    /**
     * Types of market events. Currently just
     * defines STOP event.
     * @author Sean L. Mooney
     *
     */
    public static enum MarketEvent {
        STOP
    }
}
