/*
/* Created on Jun 17, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */

package edu.iastate.jrelm.rl.rotherev.advanced;

import edu.iastate.jrelm.core.Action;
import edu.iastate.jrelm.core.ActionDomain;
import edu.iastate.jrelm.rl.RLParameters;
import edu.iastate.jrelm.rl.rotherev.RELearner;
import edu.iastate.jrelm.rl.rotherev.REPolicy;
import edu.iastate.jrelm.rl.rotherev.variant.VRELearner;
import edu.iastate.jrelm.spillover.SpilloverWeightGenerator;

//import edu.iastate.jrelm.similarity.DissimilarityMeasure;
//import edu.iastate.jrelm.spillover.SpilloverByDissimilarity;

/**
 * An extension of the VRELearner. This engine implements the same modified version 
 * of the Roth-Erev reinforcement learning algorithm with added features.
 * 
 * @author Charle Gieseler
 *
 */
public class ARELearner<I, A extends Action> 
		extends RELearner<I,A>{
	
//	private AREParameters parameters;
	
	/* ********************************************************************************
	 * 						PROBABILITY GENERATION FIELDS 
	 * ********************************************************************************/
	//Indicates which method to use to generate probabilities from propensities
//	private int probabilityMethod = USE_RELATIVE_PROPENSITY_PROBABILITY;
	
	/**
	 * Flag to use relative propensities to generate action probabilities from
	 * action propensities. This is used by default. The probability for each action 
	 * is the propensity for that action over the total propesities over all actions.
	 * 
	 * P(i) = q(i) / Sum_all_j(q(j))
	 * 
	 * Where P(i) is the probability of choosing action i, q(i) is the propensity for 
	 * action i and j runs from 1 to n (the total number of actions).
	 */
	public static final int USE_RELATIVE_PROPENSITY_PROBABILITY = 10101;
	
	/**
	 * Flag to use the Boltzman distribution to generate action probabilities from
	 * action propensities. 
	 * 
	 *  	P(i) = e ^(q(i)/T) / Sum_all_j(e ^(q(j)/T))
	 *  
	 * Where P(i) is the probability of choosing action i, q(i) is the propensity for 
	 * action i and j runs from 1 to n (the total number of actions). T is the 
	 * temperature parameter...
	 * TODO: Look up info about Gibbs/Boltzmann temperature
	 */
	public static final int USE_BOLTZMAN_PROBABILITY = 11212;
	
	public static final int[] PROBABILITY_OPTIONS = 
			{USE_RELATIVE_PROPENSITY_PROBABILITY, USE_BOLTZMAN_PROBABILITY};
	
	/* ********************************************************************************
	 * 						REWARD SPILLOVER WEIGHTING FIELDS 
	 * ********************************************************************************/
	/**
	 * Flag indicating which method of response weighting to use in updating the 
	 * propensities of actions from a given reward. This determines how much of the 
	 * reward value is "spilled over" to actions that are similar to the action that 
	 * the reward is associated with (usually the last one chosen). Similarity 
	 * between actions is defined by the given similarity measure.
	 */
	private int spilloverType = -1;
	
//	private SpilloverByDissimilarity<A,DissimilarityMeasure<A, Double>> spillover;
	private SpilloverWeightGenerator<A> spillover;
	/**
	 * TODO: Fill in explainations of the different weighting methods
	 */
	public static final int EXPONENTIAL_SPILLOVER = 20101;
	
	public static final int LOGARITHMIC_SPILLOVER = 21212;
	
	public static final int LINEAR_SPILLOVER = 22323;
	
	public static final int STANDARD_SPILLOVER = 23434;
	
	public static final int NO_SPILLOVER = 29999;
	
	/* ************************************************************************************
	 * 						 			CONSTRUCTORS
	 **************************************************************************************/
	/**
	 * Construct a RothErev learning component with parameters specified in a
	 * AREParameters object and a given ActionDomain. A default
	 * SimpleStatelessPolicy will be used.
	 * 
	 * @param learningParams - the collection of parameter settings for the 
	 * 						VRELearner
	 * @param aDomain - the domain of action to learn over.
	 */
	public ARELearner(AREParameters learningParams, 
			ActionDomain<I,A> aDomain){
		super(learningParams, aDomain);	
	}
	
	/**
	 * Construct a RothErev learning component with parameters specified in a
	 * AREParameters object.
	 * 
	 * @param learnParams
	 * @param aPolicy
	 */
	public ARELearner(AREParameters learnParams, 
			REPolicy<I,A> aPolicy){
		super(learnParams, aPolicy);
	}
	
	/*/************************************************************************************
	 * 						 			MISCELLANEOUS
	 **************************************************************************************/
	@Override
	protected void init() {
		super.init();
		
		//TODO: finish DissimilarityMeasure and spillover methods selction in 
		//AREParameters. Complete initialization here. Currently parameters
		spillover = null;
	}
	
	/*/************************************************************************************
	 * 						 SPILLOVER AND RESPONSE GENERATION
	 **************************************************************************************/

	protected double experience(int actionIndex, double reward){
	
		if(spillover == null)
			return super.experience(actionIndex, reward);
		
		double responseValue = 0;
		ActionDomain<I,A> domain = getPolicy().getActionDomain();
		
		A action = domain.getAction(actionIDList.get(actionIndex));
		
		responseValue = reward * spillover.generateWeight(action);
		
		return responseValue; 
	}
	
	/* ***********************************************************************************
	 * 							ACCESSOR METHODS
	 * ***********************************************************************************/
//	public String getName(){
//		return "Advanced Roth-Erev";
//	}
//	
//	@Override
//	public RLParameters makeParameters() {
//		return new AREParameters();
//	}
//	@Override
//	public RLParameters getParameters() {
//		return ;
//	}
//	
//	@Override
//	public void setParameters(RLParameters params) {
//		this.parameters = (AREParameters)params;
//	}
	
}
