/*
 * Created on Jun 18, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package edu.iastate.jrelm.rl.rotherev.advanced;

import java.util.Hashtable;
import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JComboBox;

import com.sun.org.apache.xalan.internal.lib.ExsltBase;


import uchicago.src.reflector.IntrospectPanel;
import uchicago.src.reflector.ListPropertyDescriptor;
import uchicago.src.reflector.PropertyButton;
import uchicago.src.sim.gui.Named;

import edu.iastate.jrelm.core.Action;
import edu.iastate.jrelm.rl.rotherev.REParameters;
import edu.iastate.jrelm.similarity.DissimilarityMeasure;
import edu.iastate.jrelm.similarity.SimpleDissimilarity;
import edu.iastate.jrelm.spillover.SpilloverByDissimilarity;
import edu.iastate.jrelm.spillover.SpilloverWeightGenerator;


/**
 * Parameters required for the Advanced version of the Roth-Erev reinforcement learning 
 * algorithm. These parameters include setting for features extended from the standard 
 * Roth-Erev algorithm. This includes: 
 *<ul>
 *	<li>Alternative methods to generate Action probabilities.</li>
 *	<li>Alternative methods of reward spillover among similar actions</li>
 *	<li>Ability to specify similar measures for Action comparison
 *</ul>
 *
 * @author Charles Gieseler
 *
 */
public class AdvancedRothErevParameters extends REParameters{
	
	/* ********************************************************************************
	 * 						PROBABILITY GENERATION FIELDS
	 * ********************************************************************************/

	//Which method to use in generating probabilities for Actions
	private int selectedProbMethod = AdvancedRothErevLearner.USE_BOLTZMAN_PROBABILITY;
			
//	private final double DEFAULT_BOLTZMANN = 9999999.0;
//	private double boltzmannCooling = DEFAULT_BOLTZMANN;
	
	/* ********************************************************************************
	 * 								SPILLOVER FIELDS
	 * ********************************************************************************/
	//Which method of reward spillover to use
	private SpilloverWeightGenerator selectedSpillover;

	//List of available spillover methods
	private Vector<SpilloverWeightGenerator> spilloverList;
	
	/* ********************************************************************************
	 * 						DESCRIPTOR CONTAINER RELATED FIELDS
	 * ********************************************************************************/
	
	//Array of names of the parameters as Strings
	private String[] paramNames = new String[] { "NumberOfActions",
		"Experimentation", "InitialPropensity", "Recency",  
		"BoltzmannCooling","ProbabilityMethod", "SpilloverMethod",
		"TestButtonParameter"};

	//Collection of parameter descriptors. Allow parameters to be displayed and
	//edited in the RePast interface.
	private Hashtable paramDescriptors = new Hashtable();
	
	PropertyButton testButtonParam;
	
	int numberOfActions =0;
	/* ********************************************************************************
	 * 									CONSTRUCTORS
	 * ********************************************************************************/
	
	/**
	 *	Construct default AdvancedRothErevParameters. This will create settings to
	 *	the same as the default MREParameters. Essentially this will run the
	 *	AdvancedRothErevLearner as a standard MRELearner with default settings.
	 */
	public AdvancedRothErevParameters(){
		super();

		init();
		selectedProbMethod = AdvancedRothErevLearner.USE_RELATIVE_PROPENSITY_PROBABILITY;
	}
	
	/**
	 * Build a AdvancedRothErevParameters object with the given learning parameter values.
	 * Essentially this will run the AdvancedRothErevLearner as a standard MRELearner 
	 * with the given settings.
	 */
	public AdvancedRothErevParameters( 
			double boltzmannCooling,
			double experimentation,
			double initialPropensity,
			int    numberOfActions,
			double recency){
		super(boltzmannCooling, experimentation, initialPropensity, recency);
		this.numberOfActions = numberOfActions;
		init();		
	}

	/**
	 * 
	 * <P>
	 * @param boltzmannCooling - cooling parameter for gibbs-boltzmann cooling method. 
	 * @param numActions
	 * @param recency
	 * @param experimentation
	 * @param initialPropensity
	 * 
	 * @param spillover 
	 * 
	 * 
	 */
	public AdvancedRothErevParameters(
			double boltzmannCooling,
			double experimentation,
			double initialPropensity,
			int numberOfActions, 
			double recency,
			Vector<SpilloverWeightGenerator> spilloverList){
		
		super(boltzmannCooling, experimentation, initialPropensity, recency);
		this.numberOfActions = numberOfActions;
		this.spilloverList = spilloverList;
		
		validateParameters();
		
		init();
	}	
	
	/* ********************************************************************************
	 * 								INITIALIZATION
	 * ********************************************************************************/
	protected void init(){
	
		buildProbabiltySelector();
		
		if(spilloverList == null)
			spilloverList = new Vector<SpilloverWeightGenerator>();
			
		buildSpilloverSelector();
		
		//Experimentation
		SimpleDissimilarity<Action> measure = new SimpleDissimilarity<Action>();
		SpilloverByDissimilarity<Action, SimpleDissimilarity<Action>> spill = 
			new ExponentialSpillover<Action, SimpleDissimilarity<Action>>(measure, -1);
		testButtonParam = new PropertyButton(spill, true);
		testButtonParam.setLabel("Spillover Settings");
	}
	
	protected void buildProbabiltySelector(){
		Hashtable probTable = new Hashtable();
		
		probTable.put(new Integer(AdvancedRothErevLearner.USE_RELATIVE_PROPENSITY_PROBABILITY), 
				"Relative Propensity");
		
		probTable.put(new Integer(AdvancedRothErevLearner.USE_BOLTZMAN_PROBABILITY), 
		"Gibbs-Boltzmann");
		
		//Build the property descriptor for the GUI
		ListPropertyDescriptor lpd = new ListPropertyDescriptor("ProbabilityMethod", probTable);

		paramDescriptors.put("ProbabilityMethod", lpd);
		
		selectedProbMethod = AdvancedRothErevLearner.USE_BOLTZMAN_PROBABILITY;
		
	}
	
	protected void buildSpilloverSelector(){
		Hashtable optionTable = new Hashtable();
		
		for(SpilloverWeightGenerator method: spilloverList){
			optionTable.put(method, method.getName());
		}
		
		//Add no-spillover option if not already present
		NoSpillover noSpill = new NoSpillover();
		if(!optionTable.containsKey(noSpill.getName())){
			optionTable.put(noSpill, noSpill.getName());
			spilloverList.add(noSpill);
		}
		
		//Add standard spillover if not already present
		StandardSpillover standard = 
				new StandardSpillover(getExperimentation(), numberOfActions);
		
		if(!optionTable.containsValue(standard.getName())){
			optionTable.put(standard, standard.getName());
			spilloverList.add(standard);
		}
		
		//Build the property descriptor for the GUI
		ListPropertyDescriptor lpd   = new ListPropertyDescriptor("SpilloverMethod", optionTable);
		
		paramDescriptors.put("SpilloverMethod", lpd);
		
		//TODO: select proper method
		selectedSpillover = standard;
//System.out.println(((JComboBox)lpd.getWidget()).getSelectedItem());		
	}
	
	/* *******************************************************
	 * 					ACCESSOR METHODS
	 * *******************************************************/

	public String getName(){
		return "Advanced Modified Roth-Erev";
	}
	
	/**
	 * Get the names of the parameters
	 * 
	 * @return Parameter names as an array of Strings
	 */
	public String[] getParameterNames(){
		return paramNames;
	}
	
	public Hashtable getParameterDescriptors(){
		return paramDescriptors;
	}
	
	public Integer getProbabilityMethod(){
		return selectedProbMethod;
	}
	
	public void setProbabilityMethod(Integer probabilitySelection){
		selectedProbMethod = probabilitySelection;
	}
	
	/**
	 * @return Flag from AdvancedRothErevLearner indicating the method of spillover to use
	 */
	public SpilloverWeightGenerator getSpilloverMethod(){
		return selectedSpillover;
	}

	public void setSpilloverMethod(SpilloverWeightGenerator spilloverSelection){
		this.selectedSpillover = spilloverSelection;
	}
	
	public Vector<SpilloverWeightGenerator> getSpilloverOptions(){return spilloverList;}
	
	public void setSpilloverOptions(Vector<SpilloverWeightGenerator> spilloverList){
		this.spilloverList = spilloverList;
		selectedSpillover = spilloverList.get(0);
	}
	
	/**
	 * Overides toSring() to return the name of the aglorithm these parameters are associated with.
	 */
//	public String toString(){return getName();}
	
	
	//**** EXPERIMENTATION ****
	public PropertyButton getTestButtonParameter(){
		return testButtonParam;
	}
	
	public void setTestButtonParameter(PropertyButton button){
		
		
	}
}
