package edu.iastate.jrelm.similarity;


import edu.iastate.jrelm.core.Action;

/**
 * Just like SimilarityMeasure, this interface is for classes that compare two Actions.
 * However, a DissimilarityMeasure returns an indication of how unlike the two Actions 
 * are. For example, a numerical DissimilarityMeasure would return greater values for 
 * Actions that are less alike. 
 *
 *
 * @author Charles Gieseler
 *
 * @param <A> - The type of Action this measure can compare.
 * @param <O> - The type that is returned to indicate dissimilarity.
 *
 * @see edu.iastate.jrelm.similarity.SimilarityMeasure
 */
public interface DissimilarityMeasure<A extends Action, O> {
	
	/*
	 * The purpose of this interface is to communicate the direction of similarity. 
	 * It is used to designate SimilarityMeasure classes that operate in the "opposite" 
	 * direction, where indicators. Besides this, there are no fundamental differences
	 * betweeen SimilarityMeasures and DissimilarityMeasures. As such, this interface 
	 * has no required extra methods.
	 */
	
	/**
	 * Performs a comparison of two Action objects and determines how similar the two are.
	 * 
	 * @param action1 - First Action.
	 * @param action2 - Second Action.
	 * @return an object representing the measure of similarity between action 1 and action2.
	 */
	public O dissimilarity(A action1, A action2);
}
