package edu.iastate.jrelm.spillover;

import edu.iastate.jrelm.core.Action;
import edu.iastate.jrelm.similarity.DissimilarityMeasure;

/**
 * SpilloverByDissimilarity classes 
 * implement the generateWeight() method with a specific weight generating 
 * funtion using a DissimilarityMeasure for comparison of Actions.
 * 
 * @see edu.iastate.jrelm.spillover.SpilloverWeightGenerator
 * 
 * @author Charles Gieseler
 *
 * @param <A>
 * @param <D>
 */
public abstract class SpilloverByDissimilarity
		<A extends Action,
		 D extends DissimilarityMeasure> extends SpilloverWeightGenerator<A>{
			 
	private D disMeasure;
	
	/**
	 * Construct a SpilloverByDissimilarity with the given DissimilarityMeasure.
	 * 
	 * @param measure - DissimilarityMeasure to use for Action comparison
	 */
	public SpilloverByDissimilarity(D measure){
		disMeasure = measure;
	}
		
	/**
	 * Get the current DissimilarityMeasure being used to compare Actions. 
	 * Returns null if none is set.
	 */
	public D getDissimilarityMeasure(){
		return disMeasure;
	}
	
	/**
	 * Set the current DissimilarityMeasure to use to compare Actions.
	 * @param measure - a DisimilarityMeasure
	 */
	public void setDissilarityMeasure(D measure){
		disMeasure = measure;
	}	
	
}
